<?php
/**
 * @file
 * Drupal RestMini module.
 */


class RestMini {

  /**
   * @var integer
   */
  protected static $errorCodeOffset = 0;

  /**
   * @var array
   */
  protected static $errorCodes = array();

  /**
   * Get error code by name, or code list, or code range.
   *
   * @param string $name
   *   Non-empty: return code by name (defaults to 'unknown')
   *   Default: empty (~ return codes list).
   * @param boolean $range
   *   TRUE: return code range array(N-first, N-last).
   *   Default: FALSE (~ ignore argument).
   * @return integer|array
   */
  public static function errorCode($name = '', $range = FALSE) {
    static $codes;

    if ($name) {
      return static::$errorCodeOffset
        + (array_key_exists($name, static::$errorCodes) ? static::$errorCodes[$name] : static::$errorCodes['unknown']);
    }

    if ($range) {
      return array(
        static::$errorCodeOffset,
        // Range of sub modules should only be 100, to allow for all sub modules within an overall range of 1000.
        static::$errorCodeOffset + 99
      );
    }

    if (!$codes) {
      $codes = static::$errorCodes; // Copy.
      if (($offset = static::$errorCodeOffset)) {
        foreach ($codes as &$code) {
          $code += $offset;
        }
        unset($code); // Iteration ref.
      }
    }

    return $codes;
  }

  /**
   * Logs to watchdog.
   *
   * Traces Exception, if $exception and the Inspect module exists.
   *
   * @param string $type
   * @param string $message
   * @param Exception|NULL $exception
   * @param mixed $variable
   * @param integer $severity
   */
  protected static function log($type, $message, $exception = NULL, $variable = NULL, $severity = WATCHDOG_ERROR) {
    if (module_exists('inspect')) {
      if ($exception) {
        inspect_trace($exception, array(
          'category' => $type,
          'message' => $message,
          'severity' => $severity,
          'wrappers' => 1,
        ));
      }
      else {
        inspect($variable, array(
          'category' => $type,
          'message' => $message,
          'severity' => $severity,
          'wrappers' => 1,
        ));
      }
    }
    else {
      watchdog(
        $type,
        (!$message && $exception) ? $exception->getMessage() : $message,
        array(),
        $severity
      );
    }
  }

}
